@@ -85,8 +85,10 @@
 #include "MsWrd1Parser.hxx"
 #include "MsWrdParser.hxx"
 #include "NisusWrtParser.hxx"
+#include "PixelPaintParser.hxx"
 #include "RagTimeParser.hxx"
 #include "RagTime5Parser.hxx"
+#include "StyleParser.hxx"
 #include "SuperPaintParser.hxx"
 #include "TeachTxtParser.hxx"
 #include "WingzParser.hxx"
@@ -143,6 +145,7 @@ try
   case MWAW_T_CLARISWORKS:
   case MWAW_T_DOCMAKER:
   case MWAW_T_EDOC:
+  case MWAW_T_FULLPAINT:
   case MWAW_T_FULLWRITE:
   case MWAW_T_GREATWORKS:
   case MWAW_T_HANMACWORDJ:
@@ -161,7 +164,9 @@ try
   case MWAW_T_MICROSOFTWORD:
   case MWAW_T_MICROSOFTWORKS:
   case MWAW_T_NISUSWRITER:
+  case MWAW_T_PIXELPAINT:
   case MWAW_T_RAGTIME:
+  case MWAW_T_STYLE:
   case MWAW_T_SUPERPAINT:
   case MWAW_T_TEACHTEXT:
   case MWAW_T_TEXEDIT:
@@ -179,21 +184,18 @@ try
   case MWAW_T_FOXBASE:
   case MWAW_T_FRAMEMAKER:
   case MWAW_T_FULLIMPACT:
-  case MWAW_T_FULLPAINT:
   case MWAW_T_INFOGENIE:
   case MWAW_T_KALEIDAGRAPH:
   case MWAW_T_MICROSOFTFILE:
   case MWAW_T_MICROSOFTMULTIPLAN:
   case MWAW_T_OVERVUE:
   case MWAW_T_PAGEMAKER:
-  case MWAW_T_PIXELPAINT:
   case MWAW_T_READYSETGO:
   case MWAW_T_SYMPOSIUM:
   case MWAW_T_TRAPEZE:
   case MWAW_T_XPRESS:
   case MWAW_T_4DIMENSION:
 
-  case MWAW_T_RESERVED3:
   case MWAW_T_RESERVED4:
   case MWAW_T_RESERVED5:
   case MWAW_T_RESERVED6:
@@ -497,6 +499,9 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
       if (header->getKind()==MWAWDocument::MWAW_K_PAINT)
         parser.reset(new ClarisWksBMParser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_FULLPAINT: // same format as MacPaint, so ok...
+      parser.reset(new MacPaintParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_GREATWORKS:
       if (header->getKind()==MWAWDocument::MWAW_K_PAINT)
         parser.reset(new GreatWksBMParser(input, rsrcParser, header));
@@ -521,6 +526,9 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
     case MWAWDocument::MWAW_T_MICROSOFTWORKS:
       parser.reset(new MsWksDRParser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_PIXELPAINT:
+      parser.reset(new PixelPaintParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_SUPERPAINT:
       parser.reset(new SuperPaintParser(input, rsrcParser, header));
       break;
@@ -536,7 +544,6 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
     case MWAWDocument::MWAW_T_FOXBASE:
     case MWAWDocument::MWAW_T_FRAMEMAKER:
     case MWAWDocument::MWAW_T_FULLIMPACT:
-    case MWAWDocument::MWAW_T_FULLPAINT:
     case MWAWDocument::MWAW_T_FULLWRITE:
     case MWAWDocument::MWAW_T_INFOGENIE:
     case MWAWDocument::MWAW_T_KALEIDAGRAPH:
@@ -555,9 +562,9 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
     case MWAWDocument::MWAW_T_NISUSWRITER:
     case MWAWDocument::MWAW_T_OVERVUE:
     case MWAWDocument::MWAW_T_PAGEMAKER:
-    case MWAWDocument::MWAW_T_PIXELPAINT:
     case MWAWDocument::MWAW_T_RAGTIME:
     case MWAWDocument::MWAW_T_READYSETGO:
+    case MWAWDocument::MWAW_T_STYLE:
     case MWAWDocument::MWAW_T_SYMPOSIUM:
     case MWAWDocument::MWAW_T_TEACHTEXT:
     case MWAWDocument::MWAW_T_TEXEDIT:
@@ -569,7 +576,6 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED3:
     case MWAWDocument::MWAW_T_RESERVED4:
     case MWAWDocument::MWAW_T_RESERVED5:
     case MWAWDocument::MWAW_T_RESERVED6:
@@ -601,7 +607,9 @@ shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStre
       break;
     case MWAWDocument::MWAW_T_ACTA:
     case MWAWDocument::MWAW_T_ADOBEILLUSTRATOR:
+    case MWAWDocument::MWAW_T_APPLEPICT:
     case MWAWDocument::MWAW_T_BEAGLEWORKS:
+    case MWAWDocument::MWAW_T_CLARISDRAW:
     case MWAWDocument::MWAW_T_CLARISRESOLVE:
     case MWAWDocument::MWAW_T_DBASE:
     case MWAWDocument::MWAW_T_DOCMAKER:
@@ -639,6 +647,7 @@ shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStre
     case MWAWDocument::MWAW_T_PIXELPAINT:
     case MWAWDocument::MWAW_T_RAGTIME:
     case MWAWDocument::MWAW_T_READYSETGO:
+    case MWAWDocument::MWAW_T_STYLE:
     case MWAWDocument::MWAW_T_SUPERPAINT:
     case MWAWDocument::MWAW_T_SYMPOSIUM:
     case MWAWDocument::MWAW_T_TEACHTEXT:
@@ -651,9 +660,6 @@ shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStre
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED1:
-    case MWAWDocument::MWAW_T_RESERVED2:
-    case MWAWDocument::MWAW_T_RESERVED3:
     case MWAWDocument::MWAW_T_RESERVED4:
     case MWAWDocument::MWAW_T_RESERVED5:
     case MWAWDocument::MWAW_T_RESERVED6:
@@ -717,6 +723,8 @@ shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStream
     // no spreadsheet, but some database
     case MWAWDocument::MWAW_T_ACTA:
     case MWAWDocument::MWAW_T_ADOBEILLUSTRATOR:
+    case MWAWDocument::MWAW_T_APPLEPICT:
+    case MWAWDocument::MWAW_T_CLARISDRAW:
     case MWAWDocument::MWAW_T_DBASE:
     case MWAWDocument::MWAW_T_DOCMAKER:
     case MWAWDocument::MWAW_T_EDOC:
@@ -748,6 +756,7 @@ shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStream
     case MWAWDocument::MWAW_T_PIXELPAINT:
     case MWAWDocument::MWAW_T_RAGTIME:
     case MWAWDocument::MWAW_T_READYSETGO:
+    case MWAWDocument::MWAW_T_STYLE:
     case MWAWDocument::MWAW_T_SUPERPAINT:
     case MWAWDocument::MWAW_T_SYMPOSIUM:
     case MWAWDocument::MWAW_T_TEACHTEXT:
@@ -758,9 +767,6 @@ shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStream
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED1:
-    case MWAWDocument::MWAW_T_RESERVED2:
-    case MWAWDocument::MWAW_T_RESERVED3:
     case MWAWDocument::MWAW_T_RESERVED4:
     case MWAWDocument::MWAW_T_RESERVED5:
     case MWAWDocument::MWAW_T_RESERVED6:
@@ -855,6 +861,9 @@ shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MW
       else
         parser.reset(new RagTime5Parser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_STYLE:
+      parser.reset(new StyleParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_TEACHTEXT:
     case MWAWDocument::MWAW_T_TEXEDIT:
       parser.reset(new TeachTxtParser(input, rsrcParser, header));
@@ -870,6 +879,8 @@ shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MW
       break;
 
     case MWAWDocument::MWAW_T_ADOBEILLUSTRATOR:
+    case MWAWDocument::MWAW_T_APPLEPICT:
+    case MWAWDocument::MWAW_T_CLARISDRAW:
     case MWAWDocument::MWAW_T_CLARISRESOLVE:
     case MWAWDocument::MWAW_T_DBASE:
     case MWAWDocument::MWAW_T_FAMILYTREEMAKER:
@@ -897,9 +908,6 @@ shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MW
     case MWAWDocument::MWAW_T_XPRESS:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED1:
-    case MWAWDocument::MWAW_T_RESERVED2:
-    case MWAWDocument::MWAW_T_RESERVED3:
     case MWAWDocument::MWAW_T_RESERVED4:
     case MWAWDocument::MWAW_T_RESERVED5:
     case MWAWDocument::MWAW_T_RESERVED6:
